"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Actor = void 0;
const bson_objectid_1 = __importDefault(require("bson-objectid"));
const entity_base_1 = require("../../common/entity.base");
class Actor extends entity_base_1.Entity {
    get username() {
        return this.attr.username;
    }
    getJSONLD(url) {
        if (!url.href.endsWith('/')) {
            url.href += '/';
        }
        const id = this.id.toHexString();
        const actor = new URL(`actor/${id}`, url.href);
        const publicKey = new URL(`key/${id}`, url.href);
        const inbox = new URL(`inbox/${id}`, url.href);
        const outbox = new URL(`outbox/${id}`, url.href);
        return {
            '@context': [
                'https://www.w3.org/ns/activitystreams',
                'https://w3id.org/security/v1'
            ],
            type: 'Person',
            id: actor.href,
            inbox: inbox.href,
            outbox: outbox.href,
            username: this.attr.username,
            preferredUsername: this.attr.preferredUsername,
            publicKey: {
                id: publicKey.href,
                owner: actor.href,
                publicKeyPem: this.attr.publicKey
            }
        };
    }
    static create(data) {
        return new Actor({
            id: data.id instanceof bson_objectid_1.default ? data.id : undefined,
            username: data.username,
            preferredUsername: data.preferredUsername || data.username,
            publicKey: data.publicKey,
            privateKey: data.privateKey
        });
    }
}
exports.Actor = Actor;
//# sourceMappingURL=actor.entity.js.map